MetricSelection
===============

.. currentmodule:: pykeen.checkpoints

.. autoclass:: MetricSelection
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MetricSelection.maximize
      ~MetricSelection.prefix

   .. rubric:: Attributes Documentation

   .. autoattribute:: maximize
   .. autoattribute:: prefix
